
# This file was generated by 'versioneer.py' (0.14) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.23.2+1.g67a89c7'
version_full = '67a89c78871b234ffad53b23e8e4a76bf1fe766c'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

